package com.atlassian.confluence.rpc.soap;

import com.atlassian.confluence.importexport.ImportExportManager;
import com.atlassian.confluence.pages.BlogPost;
import com.atlassian.confluence.pages.Page;
import com.atlassian.confluence.security.PermissionManager;
import com.atlassian.confluence.security.SpacePermissionManager;
import com.atlassian.confluence.setup.BootstrapManager;
import com.atlassian.confluence.setup.BootstrapUtils;
import com.atlassian.confluence.setup.DefaultBootstrapManager;
import com.atlassian.confluence.setup.settings.SettingsManager;
import com.atlassian.confluence.setup.settings.Settings;
import com.atlassian.confluence.spaces.Space;
import com.atlassian.confluence.user.UserAccessor;
import com.atlassian.confluence.util.GeneralUtil;
import com.atlassian.confluence.rpc.*;
import com.atlassian.confluence.cache.CacheConfigurationLoader;
import com.atlassian.confluence.cache.tangosol.TangosolCacheConfigurationLoader;
import com.atlassian.confluence.cluster.DefaultClusterConfigurationHelper;
import com.atlassian.confluence.cluster.tangosol.TangosolClusterManager;
import com.atlassian.user.User;
import com.mockobjects.dynamic.Mock;
import org.springframework.context.support.StaticApplicationContext;
import com.atlassian.spring.container.ContainerManager;
import com.atlassian.spring.container.SpringTestContainerContext;
import com.atlassian.config.ApplicationConfig;
import com.atlassian.config.db.HibernateConfig;
import junit.framework.TestCase;

public abstract class AbstractSoapTestCase extends TestCase
{
    private static final CacheConfigurationLoader cacheConfigLoader = new TangosolCacheConfigurationLoader();

    protected User user;
    protected Mock mockPermissionManager;
    protected Mock mockSpacePermissionManager;
    protected Mock mockImportExportManager;
    protected UserAccessor userAccessor;
    protected Mock mockBootstrapManager = new Mock(BootstrapManager.class);
    protected Mock mockSettingsManager;
    protected static final String TEST_BASE_URL = "http://foo.com";

    public void setUp() throws Exception
    {
        super.setUp();

        cacheConfigLoader.loadConfiguration(false);
        BootstrapUtils.setBootstrapContext(null);
        BootstrapUtils.setBootstrapManager(null);
        BootstrapUtils.setBootstrapManager(createBootstrapManagerForTests());


        userAccessor = UserTestHelper.getTestUserAccessor();
        GeneralUtil.setUserAccessor(userAccessor);

        user = userAccessor.createUser("bob");

        // setup mock objects
        mockPermissionManager = new Mock(PermissionManager.class);
        mockSpacePermissionManager = new Mock(SpacePermissionManager.class);
        mockImportExportManager = new Mock(ImportExportManager.class);

        // this is for soap service beans that get the baseUrl via the settingsManager
        mockSettingsManager = new Mock(SettingsManager.class);
        Settings settings = new Settings();
        settings.setBaseUrl(TEST_BASE_URL);
        mockSettingsManager.matchAndReturn("getGlobalSettings", settings);

        // this hack is for beans that cannot get hold of a settings manager via injection (for example RemoteSpaceSummary) and need to go via ContainerManager.
        SettingsManager settingsManager = new MemorySettingsManager();
        settingsManager.getGlobalSettings().setBaseUrl(TEST_BASE_URL);
        StaticApplicationContext testContext = new StaticApplicationContext();
        testContext.getBeanFactory().registerSingleton("settingsManager", settingsManager);
        testContext.getBeanFactory().registerSingleton("colourSchemeManager", new StubColourSchemeManager());
        testContext.refresh();
        ContainerManager.getInstance().setContainerContext(new SpringTestContainerContext(testContext));
    }

    private BootstrapManager createBootstrapManagerForTests()
    {
        DefaultBootstrapManager bootstrapManager = new DefaultBootstrapManager();
        ApplicationConfig appConfig = new ApplicationConfig();
        HibernateConfig hibernateConfig = new HibernateConfig();

        appConfig.setConfigurationPersister(new ConfluenceConfigurationPersisterForTests());
        hibernateConfig.setApplicationConfig(appConfig);

        DefaultClusterConfigurationHelper clusterConfigurationHelper = new DefaultClusterConfigurationHelper();
        clusterConfigurationHelper.setApplicationConfig(appConfig);
        clusterConfigurationHelper.setCacheConfigLoader(cacheConfigLoader);
        clusterConfigurationHelper.setClusterManager(new TangosolClusterManager());

        bootstrapManager.setApplicationConfig(appConfig);
        bootstrapManager.setHibernateConfig(hibernateConfig);
        bootstrapManager.setClusterConfigurationHelper(clusterConfigurationHelper);
        return bootstrapManager;

    }

    public void tearDown() throws Exception
    {
        super.tearDown();

        UserTestHelper.removeAllTestEntities(userAccessor);
    }

    protected Page makePage(Space space, int id, String title)
    {
        Page p = new Page();
        p.setTitle(title);
        p.setId(id);
        p.setSpace(space);
        p.setContentStatus(Page.CURRENT);
        return p;
    }

    protected BlogPost makeBlogPost(Space space, int id, String title)
    {
        BlogPost blogPost = new BlogPost();
        blogPost.setId(id);
        blogPost.setTitle(title);
        blogPost.setSpace(space);
        return blogPost;
    }

    protected Space makeSpace(String key)
    {
        Space space = new Space();
        space.setKey(key);
        space.setName("A Space name");
        return space;
    }

}