package com.atlassian.confluence.extra.userinfo;

import com.atlassian.renderer.v2.macro.BaseMacro;
import com.atlassian.renderer.v2.macro.MacroException;
import com.atlassian.renderer.v2.RenderMode;
import com.atlassian.renderer.v2.RenderUtils;
import com.atlassian.renderer.v2.SubRenderer;
import com.atlassian.renderer.RenderContext;
import com.atlassian.user.UserManager;
import com.atlassian.user.User;
import com.atlassian.user.EntityException;
import com.atlassian.confluence.renderer.radeox.macros.MacroUtils;
import com.atlassian.confluence.util.velocity.VelocityUtils;
import com.opensymphony.util.TextUtils;

import java.util.Map;

import org.apache.log4j.Category;

public class UserInformationMacro extends BaseMacro
{
    public static final Category log = Category.getInstance(UserInformationMacro.class);

    private UserInformationManager userInformationManager;
    private UserManager userManager;
    private SubRenderer subRenderer;

    public boolean isInline()
    {
        return false;
    }

    public boolean hasBody()
    {
        return false;
    }

    public RenderMode getBodyRenderMode()
    {
        return RenderMode.NO_RENDER;
    }

    public String execute(Map parameters, String body, RenderContext renderContext) throws MacroException
    {
        String username = (String) parameters.get("user");

        if (!TextUtils.stringSet(username))
        {
            return RenderUtils.error("No username supplied");
        }

        User user;
        try
        {
            user = userManager.getUser(username);
        }
        catch (EntityException e)
        {
            return RenderUtils.error("Error retrieving user: " + username);
        }

        if (user == null)
            return RenderUtils.error("User does not exist: " + username);

        Map contextMap = MacroUtils.defaultVelocityContext();
        contextMap.put("user", user);
        contextMap.put("userInfo", userInformationManager.getUserInformation(username));
        contextMap.put("presence", new PresenceRenderer(subRenderer, renderContext));


        try
        {
            return VelocityUtils.getRenderedTemplate("templates/extra/userinfo/userinfomacro.vm", contextMap);
        }
        catch (Exception e)
        {
            log.error("Error while trying to display user information!", e);
            throw new MacroException(e.getMessage());
        }
    }

    public void setUserInformationManager(UserInformationManager userInformationManager)
    {
        this.userInformationManager = userInformationManager;
    }

    public void setUserManager(UserManager userManager)
    {
        this.userManager = userManager;
    }

    public void setSubRenderer(SubRenderer subRenderer)
    {
        this.subRenderer = subRenderer;
    }
}
